@@ -2,7 +2,7 @@ import sys
 import os
 import argparse
 from . import configloader
-from .helpers import DockerTool, has_docker, is_windows, communicate
+from .helpers import DockerTool, has_docker, is_linux
 
 CONFIG_DEFAULT = ".gitlab-ci.yml"
 
@@ -65,18 +65,24 @@ def run(args=None):
         parser.print_usage()
         sys.exit(1)
     else:
-        fix_ownership = True
+        fix_ownership = has_docker()
         if options.no_docker:
             config["hide_docker"] = True
             fix_ownership = False
 
+        if not configloader.job_docker_image(config, jobname):
+            fix_ownership = False
+
+        if not is_linux():
+            fix_ownership = False
+
         if options.error_shell:
             config["error_shell"] = [options.error_shell]
         try:
             execute_job(config, jobname, recurse=options.FULL)
         finally:
-            if fix_ownership and has_docker():
-                if not is_windows():
+            if has_docker() and fix_ownership:
+                if is_linux():
                     print("Fixing up local file ownerships..")
                     dt = DockerTool()
                     dt.image = "alpine:latest"
